@@ -8,6 +8,7 @@ from twilio.rest.resources import AuthorizedConnectApps
 from twilio.rest.resources import Calls
 from twilio.rest.resources import CallerIds
 from twilio.rest.resources import Queues
+from twilio.rest.resources import Members
 from twilio.rest.resources import ConnectApps
 from twilio.rest.resources import Notifications
 from twilio.rest.resources import Recordings
@@ -17,8 +18,7 @@ from twilio.rest.resources import Participants
 from twilio.rest.resources import PhoneNumbers
 from twilio.rest.resources import Conferences
 from twilio.rest.resources import Sandboxes
-from urllib import urlencode
-from urlparse import urljoin
+from twilio.rest.resources import Usage
 
 
 def find_credentials():
@@ -77,7 +77,8 @@ class TwilioRestClient(object):
 
         headers = {
             "User-Agent": "twilio-python",
-            }
+            "Accept-Charset": "utf-8",
+        }
 
         resp = make_request(method, uri, auth=self.auth, data=data,
                             params=params, headers=headers)
@@ -129,6 +130,7 @@ values from your Twilio Account at https://www.twilio.com/user/account.
         self.conferences = Conferences(account_uri, auth)
         self.queues = Queues(account_uri, auth)
         self.sandboxes = Sandboxes(account_uri, auth)
+        self.usage = Usage(account_uri, auth)
 
         self.auth = auth
         self.account_uri = account_uri
@@ -140,3 +142,11 @@ values from your Twilio Account at https://www.twilio.com/user/account.
         """
         base_uri = "%s/Conferences/%s" % (self.account_uri, conference_sid)
         return Participants(base_uri, self.auth)
+
+    def members(self, queue_sid):
+        """
+        Return a :class:`Members` instance for the :class:`Queue`
+        with the given queue_sid
+        """
+        base_uri = "%s/Queues/%s" % (self.account_uri, queue_sid)
+        return Members(base_uri, self.auth)
